@@ -24,7 +24,7 @@ class Scanner(object):
     def __init__(self, on_success):
         self.zeroconf = Zeroconf()
         self.listener = Listener(on_success=on_success)
-        ServiceBrowser(self.zeroconf, "_bond._tcp.local.", self.listener)
+        browser = ServiceBrowser(self.zeroconf, "_bond._tcp.local.", self.listener)    # noqa: F841
 
     def __del__(self):
         del self.listener
